@@ -10,7 +10,7 @@ class Firebase(object):
 		
 		# initialize firestore.
 		# (in classes.config)
-		cred = credentials.Certificate(credentials) # must still be edited through env variables.
+		cred = _credentials_.Certificate(credentials) # must still be edited through env variables.
 		firebase_admin.initialize_app(cred)
 		self.db = firestore.client()
 
